PluginIndices

Struct PluginIndices 

pub struct PluginIndices { /* private fields */ }
Auto-generated bindings for index of the exports of plugin.

This is an implementation detail of PluginPre and can be constructed if needed as well.

For more information see Plugin as well.

Implementations

Source

impl PluginIndices

pub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<Self>

Creates a new copy of PluginIndices bindings which can then be used to instantiate into a particular store.

This method may fail if the component does not have the required exports.

pub fn load( &self, store: impl AsContextMut, instance: &Instance, ) -> Result<Plugin>

Uses the indices stored in self to load an instance of Plugin from the instance provided.

Note that at this time this method will additionally perform type-checks of all exports.