pub struct WasmHostState {
pub table: ResourceTable,
pub wasi: WasiCtx,
pub properties: HashMap<String, Value>,
pub registry: Arc<Mutex<Registry>>,
pub call_depth: Arc<AtomicUsize>,
pub limits: StoreLimits,
pub state_store: StateStore,
pub capabilities: WasmCapabilities,
}Fields
table: ResourceTablewasi: WasiCtxproperties: HashMap<String, Value>registry: Arc<Mutex<Registry>>call_depth: Arc<AtomicUsize>limits: StoreLimitsstate_store: StateStorecapabilities: WasmCapabilitiesTrait Implementations
impl Host for WasmHostState
impl Host for WasmHostState
impl Host for WasmHostState
Sourceimpl HostWithStore<WasmHostState> for HasSelf<WasmHostState>
impl HostWithStore<WasmHostState> for HasSelf<WasmHostState>
Sourceasync fn camel_call(
store: &Accessor<WasmHostState, HasSelf<WasmHostState>>,
uri: String,
payload: String,
) -> Result<String, WasmError>
async fn camel_call( store: &Accessor<WasmHostState, HasSelf<WasmHostState>>, uri: String, payload: String, ) -> Result<String, WasmError>
Invoke any Camel endpoint asynchronously.
Returns the response body as a string (JSON-encoded for structured data).
TODO(WIT-009): Only string payloads are supported; binary/bytes support is deferred.
Sourceasync fn camel_poll(
store: &Accessor<WasmHostState, HasSelf<WasmHostState>>,
uri: String,
timeout_ms: u32,
) -> Result<String, WasmError>
async fn camel_poll( store: &Accessor<WasmHostState, HasSelf<WasmHostState>>, uri: String, timeout_ms: u32, ) -> Result<String, WasmError>
Poll an endpoint for a message asynchronously (pull model).
Returns the body as a string, or an error on timeout/failure.
Sourcefn get_property(
store: Access<'_, WasmHostState, HasSelf<WasmHostState>>,
key: String,
) -> Option<String>
fn get_property( store: Access<'_, WasmHostState, HasSelf<WasmHostState>>, key: String, ) -> Option<String>
Read a property from the host Exchange.
Sourcefn set_property(
store: Access<'_, WasmHostState, HasSelf<WasmHostState>>,
key: String,
value: String,
)
fn set_property( store: Access<'_, WasmHostState, HasSelf<WasmHostState>>, key: String, value: String, )
Write a property to the host Exchange.
Sourcefn host_store(
store: Access<'_, WasmHostState, HasSelf<WasmHostState>>,
key: String,
value: String,
) -> Result<(), WasmError>
fn host_store( store: Access<'_, WasmHostState, HasSelf<WasmHostState>>, key: String, value: String, ) -> Result<(), WasmError>
Store a value that persists across process() calls for this route endpoint.
State is scoped per endpoint — different routes using the same plugin
get independent state stores.
Sourceimpl HostWithStore<WasmHostState> for HasSelf<WasmHostState>
impl HostWithStore<WasmHostState> for HasSelf<WasmHostState>
Sourceasync fn camel_call(
store: &Accessor<WasmHostState, HasSelf<WasmHostState>>,
uri: String,
payload: String,
) -> Result<String, WasmError>
async fn camel_call( store: &Accessor<WasmHostState, HasSelf<WasmHostState>>, uri: String, payload: String, ) -> Result<String, WasmError>
Invoke any Camel endpoint asynchronously.
Returns the response body as a string (JSON-encoded for structured data).
TODO(WIT-009): Only string payloads are supported; binary/bytes support is deferred.
Sourceasync fn camel_poll(
store: &Accessor<WasmHostState, HasSelf<WasmHostState>>,
uri: String,
timeout_ms: u32,
) -> Result<String, WasmError>
async fn camel_poll( store: &Accessor<WasmHostState, HasSelf<WasmHostState>>, uri: String, timeout_ms: u32, ) -> Result<String, WasmError>
Poll an endpoint for a message asynchronously (pull model).
Returns the body as a string, or an error on timeout/failure.
Sourcefn get_property(
store: Access<'_, WasmHostState, HasSelf<WasmHostState>>,
key: String,
) -> Option<String>
fn get_property( store: Access<'_, WasmHostState, HasSelf<WasmHostState>>, key: String, ) -> Option<String>
Read a property from the host Exchange.
Sourcefn set_property(
store: Access<'_, WasmHostState, HasSelf<WasmHostState>>,
key: String,
value: String,
)
fn set_property( store: Access<'_, WasmHostState, HasSelf<WasmHostState>>, key: String, value: String, )
Write a property to the host Exchange.
Sourcefn host_store(
store: Access<'_, WasmHostState, HasSelf<WasmHostState>>,
key: String,
value: String,
) -> Result<(), WasmError>
fn host_store( store: Access<'_, WasmHostState, HasSelf<WasmHostState>>, key: String, value: String, ) -> Result<(), WasmError>
Store a value that persists across process() calls for this route endpoint.
State is scoped per endpoint — different routes using the same plugin
get independent state stores.
Sourceimpl HostWithStore<WasmHostState> for HasSelf<WasmHostState>
impl HostWithStore<WasmHostState> for HasSelf<WasmHostState>
Sourceasync fn camel_call(
store: &Accessor<WasmHostState, HasSelf<WasmHostState>>,
uri: String,
payload: String,
) -> Result<String, WasmError>
async fn camel_call( store: &Accessor<WasmHostState, HasSelf<WasmHostState>>, uri: String, payload: String, ) -> Result<String, WasmError>
Invoke any Camel endpoint asynchronously.
Returns the response body as a string (JSON-encoded for structured data).
TODO(WIT-009): Only string payloads are supported; binary/bytes support is deferred.
Sourceasync fn camel_poll(
store: &Accessor<WasmHostState, HasSelf<WasmHostState>>,
uri: String,
timeout_ms: u32,
) -> Result<String, WasmError>
async fn camel_poll( store: &Accessor<WasmHostState, HasSelf<WasmHostState>>, uri: String, timeout_ms: u32, ) -> Result<String, WasmError>
Poll an endpoint for a message asynchronously (pull model).
Returns the body as a string, or an error on timeout/failure.
Sourcefn get_property(
store: Access<'_, WasmHostState, HasSelf<WasmHostState>>,
key: String,
) -> Option<String>
fn get_property( store: Access<'_, WasmHostState, HasSelf<WasmHostState>>, key: String, ) -> Option<String>
Read a property from the host Exchange.
Sourcefn set_property(
store: Access<'_, WasmHostState, HasSelf<WasmHostState>>,
key: String,
value: String,
)
fn set_property( store: Access<'_, WasmHostState, HasSelf<WasmHostState>>, key: String, value: String, )
Write a property to the host Exchange.
Sourcefn host_store(
store: Access<'_, WasmHostState, HasSelf<WasmHostState>>,
key: String,
value: String,
) -> Result<(), WasmError>
fn host_store( store: Access<'_, WasmHostState, HasSelf<WasmHostState>>, key: String, value: String, ) -> Result<(), WasmError>
Store a value that persists across process() calls for this route endpoint.
State is scoped per endpoint — different routes using the same plugin
get independent state stores.
Sourceimpl WasiView for WasmHostState
impl WasiView for WasmHostState
Sourcefn ctx(&mut self) -> WasiCtxView<'_>
fn ctx(&mut self) -> WasiCtxView<'_>
Yields mutable access to the
WasiCtx configuration used for this
context.Auto Trait Implementations
impl !RefUnwindSafe for WasmHostState
impl !Sync for WasmHostState
impl !UnwindSafe for WasmHostState
impl Freeze for WasmHostState
impl Send for WasmHostState
impl Unpin for WasmHostState
impl UnsafeUnpin for WasmHostState