Module source_bindings

Module source_bindings 

Modules

camel

Structs

Auto-generated bindings for an instance a component which implements the world source.
SourceIndices
Auto-generated bindings for index of the exports of source.
SourcePre
Auto-generated bindings for a pre-instantiated version of a component which implements the world source.

Type Aliases

HttpListener
SourcePlan
WasmError
WasmExchange