Host

pub trait Host: HostHttpListener + Send {
    // Required method
    fn is_cancelled(&mut self) -> bool;
}

Required Methods

fn is_cancelled(&mut self) -> bool

Check if the host has cancelled the run loop. Stays sync — a quick peek that must not yield (called in tight guest loops).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<_T: Host + ?Sized + Send> Host for &mut _T

Source

fn is_cancelled(&mut self) -> bool

Check if the host has cancelled the run loop. Stays sync — a quick peek that must not yield (called in tight guest loops).

Implementors