pub trait Host: HostHttpListener + Send {
// Required method
fn is_cancelled(&mut self) -> bool;
}Required Methods
Sourcefn is_cancelled(&mut self) -> bool
fn is_cancelled(&mut self) -> bool
Check if the host has cancelled the run loop. Stays sync — a quick peek that must not yield (called in tight guest loops).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<_T: Host + ?Sized + Send> Host for &mut _T
impl<_T: Host + ?Sized + Send> Host for &mut _T
Sourcefn is_cancelled(&mut self) -> bool
fn is_cancelled(&mut self) -> bool
Check if the host has cancelled the run loop. Stays sync — a quick peek that must not yield (called in tight guest loops).